Welcome to HoloSpy's documentation!
***********************************
**HoloSpy** is a Python package extending the functionality for multi-dimensional
data analysis provided by the `HyperSpy <https://hyperspy.org/>`_ library. It is
aimed at helping with the analysis of (off-axis) electron holography data.

Check out the :ref:`installation` section for further information, including
how to start using this project.

.. note::

   This is an open-source community project: everyone is welcome to contribute.
   Please read our (see :ref:`contributing_label`) guidelines and get started!

Contents
========

.. toctree::
   :maxdepth: 2

   user_guide/index.rst
   api/index.rst
   contributing.rst
   changes.rst


.. include:: citing.rst

.. include:: license.rst

